@@ -63,7 +63,7 @@ class IPCMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
 
     metadata = metadata_module.PrimitiveMetadata({
         'id': '69845479-0b61-3578-b382-972cd0e61d69',
-        'version': '2.0.12',
+        'version': '2.0.13',
         'name': 'IPCMB feature selector',
         'keywords': ['rpi primitives'],
         'source': {
@@ -75,7 +75,8 @@ class IPCMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
         },
         'installation':[{
             'type': 'PIP',
-            'package_uri': 'rpi_featureSelection_python_tools'
+            'package': 'rpi_featureSelection_python_tools',
+	    'version': '2.0.13'
         }],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.IPCMBplus_Selector',
         'algorithm_types': 'MINIMUM_REDUNDANCY_FEATURE_SELECTION',
@@ -106,7 +107,7 @@ class IPCMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
         if self._fitted:
             return CallResult(None)
 
-        if self._training_inputs.any() == None or self._training_outputs.any() == None:
+        if self._training_inputs.any() == None or self._training_outputs.any() == None: 
             raise ValueError('Missing training data, or missing values exist.')
 
         scipy.io.savemat('rpi_data.mat', mdict={'traindata': self._training_inputs, 'trainlabel': self._training_outputs, 'hm_bins': hyperparams['n_bins']})
